@@ -1,11 +1,10 @@
 import asyncio
 import functools
+import simplejson as json
 import socket
 import time
 from functools import partial
 
-import simplejson as json
-
 from jotdx.consts import CONFIG
 from jotdx.consts import EX_HOSTS
 from jotdx.consts import GP_HOSTS
@@ -131,6 +130,10 @@ def server(index=None, limit=5, console=False, sync=True):
     return [(item['addr'], item['port']) for item in server]
 
 
+def check_server(console=False, limit=5, sync=True) -> None:
+    return bestip(console=console, limit=limit, sync=sync)
+
+
 def bestip(console=False, limit=5, sync=True) -> None:
     config_ = get_config_path('config.json')
     default = dict(CONFIG)
